"""General API helpers for the approval app."""

from rest_framework import permissions, serializers


class CustomDjangoModelPermissions(permissions.DjangoModelPermissions):
    """Ensures has the correct permissions for the model."""

    perms_map = {
        "GET": ["%(app_label)s.view_%(model_name)s"],
        "OPTIONS": ["%(app_label)s.view_%(model_name)s"],
        "HEAD": ["%(app_label)s.view_%(model_name)s"],
        "POST": ["%(app_label)s.add_%(model_name)s"],
        "PUT": ["%(app_label)s.change_%(model_name)s"],
        "PATCH": ["%(app_label)s.change_%(model_name)s"],
        "DELETE": ["%(app_label)s.delete_%(model_name)s"],
    }


class TaggedObjectRelatedField(serializers.RelatedField):
    """A custom field to use for the `tagged_object` generic relationship."""

    def to_representation(self, value):
        """Serialize tagged objects to a simple textual representation."""
        if hasattr(value, "get_api_url"):
            return f"{value.get_api_url()}{value.id}/"
        if hasattr(value, "get_absolute_url"):  # pragma: no cover
            return value.get_absolute_url()
        else:  # pragma: no cover
            return value.id
