"""Notification bodies for the inventree-approval app."""

from django.utils.translation import gettext_lazy as _

from common.notifications import NotificationBody

ApprovalStarted = NotificationBody(
    name=_("New approval started"),
    slug="{app_label}.new_{model_name}_approval",
    message=_("An approval was started for a order that is assigned to you"),
    template="email/new_order_assigned.html",
)
"""Send when an approval for a order was started."""

ApprovalDecisionAdded = NotificationBody(
    name=_("New approval decision"),
    slug="{app_label}.new_{model_name}_approval_decision",
    message=_("An approval decision was added for a order that is assigned to you"),
    template="email/order_approval_decision_added.html",
)
"""Send when an approval decision for a order was added."""

ApprovalDecisionRequested = NotificationBody(
    name=_("Approval requested"),
    slug="{app_label}.new_{model_name}_approval_request",
    message=_("Your decision was requested for an open approval"),
    template="email/approval_decision_requested.html",
)
"""Send when an approval decision was requested."""

ApprovalApproved = NotificationBody(
    name=_("Approval approved"),
    slug="{app_label}.{model_name}_approved",
    message=_("An approval for a order that is assigned to you was approved"),
    template="email/approval_decision.html",
)
"""Send when an approval for a order was approved."""

ApprovalRejected = NotificationBody(
    name=_("Approval rejected"),
    slug="{app_label}.{model_name}_rejected",
    message=_("An approval for a order that is assigned to you was rejected"),
    template="email/approval_decision.html",
)
"""Send when an approval for a order was _rejected."""

ApprovalReminder = NotificationBody(
    name=_("Reminder: Pending Approval {instance}"),
    slug="{app_label}.{model_name}_reminder",
    message=_("The approval {instance} is still open and pending decisions."),
    template="email/approval_decision.html",
)
"""Send as a reminder for an approval."""
